@@ -7,13 +7,17 @@ class Meme(object):
     def get(name=None):
         return Meme.meme_repository.get(name)
     
+    @staticmethod
+    def recommended(locale='en', count=10):
+        return Meme.meme_repository.recommended(locale, count)
+    
     class Posts(object):
         post_repository = PostRepository()
 
         @staticmethod
-        def popular(locale='en'):
-            return Meme.Posts.post_repository.popular(locale)
+        def popular(locale='en', count=10):
+            return Meme.Posts.post_repository.popular(locale, count)
         
         @staticmethod
-        def search(query):
-            return Meme.Posts.post_repository.search(query)
+        def search(query, count=10):
+            return Meme.Posts.post_repository.search(query, count)
